@@ -7,7 +7,7 @@
 #  define VTKFILTERSEXTRACTION_NO_EXPORT
 #else
 #  ifndef VTKFILTERSEXTRACTION_EXPORT
-#    ifdef vtkFiltersExtraction_EXPORTS
+#    ifdef FiltersExtraction_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSEXTRACTION_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,18 +23,20 @@
 
 #ifndef VTKFILTERSEXTRACTION_DEPRECATED
 #  define VTKFILTERSEXTRACTION_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSEXTRACTION_DEPRECATED_EXPORT VTKFILTERSEXTRACTION_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSEXTRACTION_DEPRECATED_NO_EXPORT VTKFILTERSEXTRACTION_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSEXTRACTION_NO_DEPRECATED
+#ifndef VTKFILTERSEXTRACTION_DEPRECATED_EXPORT
+#  define VTKFILTERSEXTRACTION_DEPRECATED_EXPORT VTKFILTERSEXTRACTION_EXPORT VTKFILTERSEXTRACTION_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersCoreModule.h"
-#include "vtkFiltersGeneralModule.h"
-#include "vtkFiltersStatisticsModule.h"
-
+#ifndef VTKFILTERSEXTRACTION_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSEXTRACTION_DEPRECATED_NO_EXPORT VTKFILTERSEXTRACTION_NO_EXPORT VTKFILTERSEXTRACTION_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSEXTRACTION_NO_DEPRECATED
+#    define VTKFILTERSEXTRACTION_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKFILTERSEXTRACTION_EXPORT_H */
