@@ -15,13 +15,18 @@
 #ifndef vtkVersionMacros_h
 #define vtkVersionMacros_h
 
-/* In development versions the minor component is odd and the build
-   component encodes a date in CCYYMMDD format.  In release versions
-   (or preparation of one) the minor component is even and the build
-   component is a small integer patch level.  */
-#define VTK_MAJOR_VERSION 8
+/* Note: this file is deliberately both valid C and valid C++. */
+
+#define VTK_MAJOR_VERSION 9
 #define VTK_MINOR_VERSION 2
-#define VTK_BUILD_VERSION 0
-#define VTK_VERSION "8.2.0"
+#define VTK_BUILD_VERSION 6
+#define VTK_VERSION "9.2.6"
+
+#define VTK_SOURCE_VERSION "vtk version " VTK_VERSION
+
+#define VTK_VERSION_CHECK(major, minor, build)                                                     \
+  (10000000000ULL * major + 100000000ULL * minor + build)
+#define VTK_VERSION_NUMBER                                                                         \
+  VTK_VERSION_CHECK(VTK_MAJOR_VERSION, VTK_MINOR_VERSION, VTK_BUILD_VERSION)
 
 #endif
